package com.djhk.uav.warLawLibrary.mapper;

import com.djhk.uav.warLawLibrary.domain.WarLawLibrary;

import java.util.List;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author ruoyi
 * @date 2024-11-15
 */
public interface WarLawLibraryMapper 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public WarLawLibrary selectWarLawLibraryById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param warLawLibrary 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<WarLawLibrary> selectWarLawLibraryList(WarLawLibrary warLawLibrary);

    /**
     * 新增【请填写功能名称】
     * 
     * @param warLawLibrary 【请填写功能名称】
     * @return 结果
     */
    public int insertWarLawLibrary(WarLawLibrary warLawLibrary);

    /**
     * 修改【请填写功能名称】
     * 
     * @param warLawLibrary 【请填写功能名称】
     * @return 结果
     */
    public int updateWarLawLibrary(WarLawLibrary warLawLibrary);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteWarLawLibraryById(Long id);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param id 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWarLawLibraryByIds(Long id);

    int removeByWarName(String warName);
}
